==> jc-1.4.0.tar.gz: javax/print/attribute/standard/Sides.h <==
// public final class javax.print.attribute.standard.Sides

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class 9a4c4090cffb412 javax_print_attribute_standard_Sides

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_Sides_H_
#define _JC_javax_print_attribute_standard_Sides_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_Sides$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Sides$sub_refs	_jc_javax_print_attribute_standard_Sides$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Sides$sub_nonrefs	_jc_javax_print_attribute_standard_Sides$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Sides$refs	_jc_javax_print_attribute_standard_Sides$refs;
typedef struct _jc_javax_print_attribute_standard_Sides$nonrefs	_jc_javax_print_attribute_standard_Sides$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Sides$object	_jc_javax_print_attribute_standard_Sides$object;

typedef struct _jc_javax_print_attribute_standard_Sides$fields_struct	_jc_javax_print_attribute_standard_Sides$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Sides$vmethods	_jc_javax_print_attribute_standard_Sides$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Sides$vtable	_jc_javax_print_attribute_standard_Sides$vtable;
typedef const struct _jc_javax_print_attribute_standard_Sides$vtype	_jc_javax_print_attribute_standard_Sides$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Sides$fields_struct {
	struct _jc_javax_print_attribute_standard_Sides$object	*DUPLEX;
	struct _jc_javax_print_attribute_standard_Sides$object	*ONE__5fSIDED;
	struct _jc_javax_print_attribute_standard_Sides$object	*TUMBLE;
	struct _jc_javax_print_attribute_standard_Sides$object	*TWO__5fSIDED__5fLONG__5fEDGE;
	struct _jc_javax_print_attribute_standard_Sides$object	*TWO__5fSIDED__5fSHORT__5fEDGE;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Sides;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Sides$fields_struct _jc_javax_print_attribute_standard_Sides$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Sides$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Sides$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Sides$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Sides$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Sides$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_Sides$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Sides$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Sides$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_Sides$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Sides$vmethods	javax_print_attribute_standard_Sides;
};

// Vtype
struct _jc_javax_print_attribute_standard_Sides$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Sides$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Sides$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Sides$refs {
    _jc_javax_print_attribute_standard_Sides$sub_refs	javax_print_attribute_standard_Sides;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Sides$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Sides$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Sides$sub_nonrefs	javax_print_attribute_standard_Sides;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Sides$object {
	_jc_javax_print_attribute_standard_Sides$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Sides$vtype	*vtype;
	_jc_javax_print_attribute_standard_Sides$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Sides$vtype _jc_javax_print_attribute_standard_Sides$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Sides, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Sides$class_object;

#endif	/* _JC_javax_print_attribute_standard_Sides_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/Sides.h <==
// public final class javax.print.attribute.standard.Sides

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class 9a4c4090cffb412 javax_print_attribute_standard_Sides

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_Sides_H_
#define _JC_javax_print_attribute_standard_Sides_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_Sides$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_Sides$sub_refs	_jc_javax_print_attribute_standard_Sides$sub_refs;
typedef struct _jc_javax_print_attribute_standard_Sides$sub_nonrefs	_jc_javax_print_attribute_standard_Sides$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_Sides$refs	_jc_javax_print_attribute_standard_Sides$refs;
typedef struct _jc_javax_print_attribute_standard_Sides$nonrefs	_jc_javax_print_attribute_standard_Sides$nonrefs;
typedef struct _jc_javax_print_attribute_standard_Sides$object	_jc_javax_print_attribute_standard_Sides$object;

typedef struct _jc_javax_print_attribute_standard_Sides$fields_struct	_jc_javax_print_attribute_standard_Sides$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_Sides$vmethods	_jc_javax_print_attribute_standard_Sides$vmethods;
typedef const struct _jc_javax_print_attribute_standard_Sides$vtable	_jc_javax_print_attribute_standard_Sides$vtable;
typedef const struct _jc_javax_print_attribute_standard_Sides$vtype	_jc_javax_print_attribute_standard_Sides$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_Sides$fields_struct {
	struct _jc_javax_print_attribute_standard_Sides$object	*DUPLEX;
	struct _jc_javax_print_attribute_standard_Sides$object	*ONE__5fSIDED;
	struct _jc_javax_print_attribute_standard_Sides$object	*TUMBLE;
	struct _jc_javax_print_attribute_standard_Sides$object	*TWO__5fSIDED__5fLONG__5fEDGE;
	struct _jc_javax_print_attribute_standard_Sides$object	*TWO__5fSIDED__5fSHORT__5fEDGE;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24Sides;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_Sides$fields_struct _jc_javax_print_attribute_standard_Sides$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_Sides$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Sides$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_Sides$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_Sides$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_Sides$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_Sides$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_Sides$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_Sides$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_Sides$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_Sides$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_Sides$vmethods	javax_print_attribute_standard_Sides;
};

// Vtype
struct _jc_javax_print_attribute_standard_Sides$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_Sides$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Sides$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_Sides$refs {
    _jc_javax_print_attribute_standard_Sides$sub_refs	javax_print_attribute_standard_Sides;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_Sides$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_Sides$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_Sides$sub_nonrefs	javax_print_attribute_standard_Sides;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_Sides$object {
	_jc_javax_print_attribute_standard_Sides$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_Sides$vtype	*vtype;
	_jc_javax_print_attribute_standard_Sides$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_Sides$vtype _jc_javax_print_attribute_standard_Sides$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_Sides, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_Sides$class_object;

#endif	/* _JC_javax_print_attribute_standard_Sides_H_ */
